# Django
from django.apps import AppConfig


class DjangoDeeplPoConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_deepl_po"
    verbose_name = "Django DeepL PO"
